#include "selectremotedlg.h"

#include "remote.h"

#include <QHBoxLayout>
#include <QLabel>
#include <QString>
#include <QListWidget>
#include <QListWidgetItem>
#include <QSettings>
#include <QMap>
#include <QList>
#include <QMessageBox>
#include <QPushButton>

SelectRemoteDlg::SelectRemoteDlg(QWidget *parent)
    : QDialog(parent)
{
    this->setWindowTitle(tr("Select remote"));
    this->setMinimumHeight(320);

    layout = new QHBoxLayout(this);

    alphabetList = new QListWidget(this);
    alphabetList->setMaximumWidth(96);
    layout->addWidget(alphabetList);
    connect(alphabetList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)),
                this, SLOT(alphabetItemChanged(QListWidgetItem*, QListWidgetItem*)));
    
    mfgList = new QListWidget(this);
    layout->addWidget(mfgList);
    connect(mfgList, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)),
                this, SLOT(mfgItemChanged(QListWidgetItem*, QListWidgetItem*)));

    modelList = new QListWidget(this);
    layout->addWidget(modelList);

    downloadBtn = new QPushButton(tr("Download"), this);
    layout->addWidget(downloadBtn);
    connect(downloadBtn, SIGNAL(clicked()), 
            this, SLOT(downloadRemote()));

    this->setLayout(layout);
    connect(&remoteDbMgr, SIGNAL(RemoteDBMgr::dbReady(RemoteDB*)),
            this, SLOT(setDb(RemoteDB*)));
    remoteDbMgr.getDbAsync();
    setBusy(true);
}


SelectRemoteDlg::~SelectRemoteDlg()
{
    delete layout;
}

SelectRemoteDlg::setDb(RemoteDB *db)
{
    remoteDb = db;
    setBusy(false);
}

void SelectRemoteDlg::setBusy(bool busy)
{
    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, busy);
    setEnabled(!busy);
}

void SelectRemoteDlg::alphabetItemChanged(QListWidgetItem *current,
                                      QListWidgetItem * /*previous*/)
{
    mfgList->clear();
    modelList->clear();
    if (current)
    {
        mfgList->addItems(remoteDb[current->text()].keys());
    }
}

void SelectRemoteDlg::mfgItemChanged(QListWidgetItem *current,
                                     QListWidgetItem * /*previous*/)
{
    modelList->clear();
    if (current)
    {
        QList <Remote> remotes =
           remoteDb[alphabetList->currentItem()->text()][current->text()];
        foreach(Remote remote, remotes) {
            modelList.addItem(RemoteListWidgetItem(remote));
        }
    }
}

void SelectRemoteDlg::downloadRemote()
{
    RemoteListWidgetItem *currentModel = modelList->currentItem();
    if (currentModel)
    {
        currentModel->remote().saveFile();
    }
}

